# Swift - Morm is a simple object mapper for python

Features
Swift - Morm (Swift Micro-ORM) is a free library that you can add in to your project that will help you to create easy connection and object mapper.
